@@ -59,7 +59,7 @@ def format(action=None, lister=False):
         else:
             data += (None,)
     else:
-        data = (tuple('<none>' for _ in range(len(columns))),)
+        data = (tuple('' for _ in range(len(columns))),)
 
     return columns, data
 
