@@ -16,6 +16,9 @@
 
 import copy
 import json
+import sys
+
+from six import StringIO
 
 import mock
 
@@ -27,6 +30,7 @@ ACTION_EX_DICT = {
     'id': '123',
     'name': 'some',
     'workflow_name': 'thing',
+    'workflow_namespace': '',
     'task_name': 'task1',
     'task_execution_id': "1-2-3-4",
     'state': 'RUNNING',
@@ -83,7 +87,7 @@ class TestCLIActionExecutions(base.BaseCommandTest):
         )
 
         self.assertEqual(
-            ('123', 'some', 'thing', 'task1', '1-2-3-4', 'RUNNING',
+            ('123', 'some', 'thing', '', 'task1', '1-2-3-4', 'RUNNING',
              'RUNNING somehow.', True, '1', '1'),
             result[1]
         )
@@ -139,6 +143,7 @@ class TestCLIActionExecutions(base.BaseCommandTest):
                 action_ex_dict['id'],
                 action_ex_dict['name'],
                 action_ex_dict['workflow_name'],
+                action_ex_dict['workflow_namespace'],
                 action_ex_dict['task_name'],
                 action_ex_dict['task_execution_id'],
                 action_ex_dict['state'],
@@ -153,6 +158,10 @@ class TestCLIActionExecutions(base.BaseCommandTest):
     def test_update_invalid_state(self):
         states = ['PAUSED', 'WAITING', 'DELAYED']
 
+        # Redirect the stderr so it doesn't show during tox
+        _stderr = sys.stderr
+        sys.stderr = StringIO()
+
         for state in states:
             self.assertRaises(
                 SystemExit,
@@ -161,13 +170,17 @@ class TestCLIActionExecutions(base.BaseCommandTest):
                 app_args=['id', '--state', state]
             )
 
+        # Stop the redirection
+        print(sys.stderr.getvalue())
+        sys.stderr = _stderr
+
     def test_list(self):
         self.client.action_executions.list.return_value = [ACTION_EX]
 
         result = self.call(action_ex_cmd.List)
 
         self.assertEqual(
-            [('123', 'some', 'thing', 'task1', '1-2-3-4', 'RUNNING', True,
+            [('123', 'some', 'thing', '', 'task1', '1-2-3-4', 'RUNNING', True,
               '1', '1')],
             result[1]
         )
@@ -178,7 +191,7 @@ class TestCLIActionExecutions(base.BaseCommandTest):
         result = self.call(action_ex_cmd.Get, app_args=['id'])
 
         self.assertEqual(
-            ('123', 'some', 'thing', 'task1', '1-2-3-4', 'RUNNING',
+            ('123', 'some', 'thing', '', 'task1', '1-2-3-4', 'RUNNING',
              'RUNNING somehow.', True, '1', '1'), result[1]
         )
 
