@@ -21,12 +21,14 @@ import mock
 
 from mistralclient.api.v2 import tasks
 from mistralclient.commands.v2 import tasks as task_cmd
+from mistralclient.commands.v2.tasks import TaskFormatter
 from mistralclient.tests.unit import base
 
 TASK_DICT = {
     'id': '123',
     'name': 'some',
     'workflow_name': 'thing',
+    'workflow_namespace': '',
     'workflow_execution_id': '321',
     'state': 'RUNNING',
     'state_info': None,
@@ -47,7 +49,7 @@ TASK_WITH_RESULT = tasks.Task(mock, TASK_WITH_RESULT_DICT)
 TASK_WITH_PUBLISHED = tasks.Task(mock, TASK_WITH_PUBLISHED_DICT)
 
 EXPECTED_TASK_RESULT = (
-    '123', 'some', 'thing', '321', 'RUNNING', None, '1', '1'
+    '123', 'some', 'thing', '', '321', 'RUNNING', None, '1', '1'
 )
 
 
@@ -58,6 +60,10 @@ class TestCLITasksV2(base.BaseCommandTest):
         result = self.call(task_cmd.List)
 
         self.assertEqual([EXPECTED_TASK_RESULT], result[1])
+        self.assertEqual(
+            self.client.tasks.list.call_args[1]["fields"],
+            TaskFormatter.COLUMN_FIELD_NAMES
+        )
 
     def test_list_with_workflow_execution(self):
         self.client.tasks.list.return_value = [TASK]
